@@ -3,22 +3,26 @@
 ( cd usr/lib ; rm -rf libgnt.so.0 )
 ( cd usr/lib ; ln -sf libgnt.so.0.0.0 libgnt.so.0 )
 ( cd usr/lib ; rm -rf libpurple-client.so )
-( cd usr/lib ; ln -sf libpurple-client.so.0.5.8 libpurple-client.so )
+( cd usr/lib ; ln -sf libpurple-client.so.0.6.1 libpurple-client.so )
 ( cd usr/lib ; rm -rf libpurple-client.so.0 )
-( cd usr/lib ; ln -sf libpurple-client.so.0.5.8 libpurple-client.so.0 )
+( cd usr/lib ; ln -sf libpurple-client.so.0.6.1 libpurple-client.so.0 )
 ( cd usr/lib ; rm -rf libpurple.so.0 )
-( cd usr/lib ; ln -sf libpurple.so.0.5.8 libpurple.so.0 )
+( cd usr/lib ; ln -sf libpurple.so.0.6.1 libpurple.so.0 )
 ( cd usr/lib ; rm -rf libpurple.so )
-( cd usr/lib ; ln -sf libpurple.so.0.5.8 libpurple.so )
+( cd usr/lib ; ln -sf libpurple.so.0.6.1 libpurple.so )
 ( cd usr/lib/purple-2 ; rm -rf liboscar.so.0 )
 ( cd usr/lib/purple-2 ; ln -sf liboscar.so.0.0.0 liboscar.so.0 )
+( cd usr/lib/purple-2 ; rm -rf libymsg.so.0 )
+( cd usr/lib/purple-2 ; ln -sf libymsg.so.0.0.0 libymsg.so.0 )
 ( cd usr/lib/purple-2 ; rm -rf liboscar.so )
 ( cd usr/lib/purple-2 ; ln -sf liboscar.so.0.0.0 liboscar.so )
+( cd usr/lib/purple-2 ; rm -rf libymsg.so )
+( cd usr/lib/purple-2 ; ln -sf libymsg.so.0.0.0 libymsg.so )
 ( cd usr/lib/purple-2 ; rm -rf libjabber.so )
 ( cd usr/lib/purple-2 ; ln -sf libjabber.so.0.0.0 libjabber.so )
 ( cd usr/lib/purple-2 ; rm -rf libjabber.so.0 )
 ( cd usr/lib/purple-2 ; ln -sf libjabber.so.0.0.0 libjabber.so.0 )
-#%% begin initialize pidgin-2.5.8-i586-P1
+#%% begin initialize pidgin-2.6.1-i586-P1
 if [ -x /usr/bin/gconftool-2 ]; then
     ( cd /etc/gconf/schemas ; GCONF_CONFIG_SOURCE=xml:merged:/etc/gconf/gconf.xml.defaults /usr/bin/gconftool-2 --makefile-install-rule purple.schemas )
 fi
